@@ -351,9 +351,11 @@ class Provider(AddressProvider):
             self.random_element(
                 self.secondary_address_formats))
 
-    def state(self):
+    def administrative_unit(self):
         return self.random_element(self.states)
 
+    state = administrative_unit
+
     def state_abbr(self, include_territories=True):
         """
         :returns: A random state or territory abbreviation.
