@@ -1,10 +1,8 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from .. import Provider as InternetProvider
 
 
 class Provider(InternetProvider):
-    safe_email_tlds = ('org', 'com', 'net', 'ch',)
+    safe_email_tlds = ('org', 'com', 'net', 'ch')
     free_email_domains = (
         'gmail.com',
         'hotmail.fr',
